@@ -47,18 +47,27 @@ class CausalTreeLearnHonestValidation(CausalTreeLearn):
         train_x, val_x, train_y, val_y, train_t, val_t = train_test_split(x, y, t, random_state=self.seed, shuffle=True,
                                                                           test_size=self.val_split)
 
-        num_treat, _ = get_treat_size(t)
-        self.num_treated = num_treat
-        self.num_samples = x.shape[0]
-        self.treated_share = self.num_treated / self.num_samples
         # TODO: val est?
-        self.root.num_samples = x.shape[0]
+        # num_treat, _ = get_treat_size(t)
+        # self.num_treated = num_treat
+        # self.num_samples = x.shape[0]
+        # self.treated_share = self.num_treated / self.num_samples
+        # self.root.num_samples = x.shape[0]
+        num_treat, _ = get_treat_size(val_t)
+        self.num_treated = num_treat
+        self.num_samples = val_t.shape[0]
+        self.treated_share = self.num_treated / self.num_samples
+        self.root.num_samples = val_t.shape[0]
         # ----------------------------------------------------------------
         # effect and pvals
         # ----------------------------------------------------------------
         # TODO: val est?
-        effect = tau_squared(y, t)
-        p_val = get_pval(y, t)
+        # effect = tau_squared(y, t)
+        # p_val = get_pval(y, t)
+        # self.root.effect = effect
+        # self.root.p_val = p_val
+        effect = tau_squared(val_y, val_t)
+        p_val = get_pval(val_y, val_t)
         self.root.effect = effect
         self.root.p_val = p_val
 
@@ -84,7 +93,7 @@ class CausalTreeLearnHonestValidation(CausalTreeLearn):
         self.root.control_mean = np.mean(val_y[val_t == 0])
         self.root.treatment_mean = np.mean(val_y[val_t == 1])
 
-        self.root.num_samples = x.shape[0]
+        self.root.num_samples = val_x.shape[0]
 
         self._fit(self.root, train_x, train_y, train_t, val_x, val_y, val_t)
 
@@ -149,25 +158,38 @@ class CausalTreeLearnHonestValidation(CausalTreeLearn):
                         best_tb_var, best_fb_var = (tb_var, fb_var)
                 else:
                     for x in batch(unique_vals, self.feature_batch_size):
-                        split_obj, upper_obj, lower_obj, value = self._eval_fast(train_x, train_y, train_t, val_x,
-                                                                                 val_y, val_t, x, col)
 
-                        (train_x1, train_x2, train_y1, train_y2, train_t1, train_t2) \
-                            = divide_set(train_x, train_y, train_t, col, value)
+                        return_val = self._eval_fast(train_x, train_y, train_t, val_x, val_y, val_t, x, col)
 
-                        # ----------------------------------------------------------------
-                        # Honest penalty
-                        # ----------------------------------------------------------------
-                        var_treat1, var_control1 = variance(train_y1, train_t1)
-                        var_treat2, var_control2 = variance(train_y2, train_t2)
+                        split_obj, upper_obj, lower_obj = return_val[0], return_val[1], return_val[2]
+                        upper_var_treated, upper_var_control = return_val[3], return_val[4]
+                        lower_var_treated, lower_var_control = return_val[5], return_val[6]
+                        value = return_val[7]
+
+                        tb_var = (1 + self.train_to_est_ratio) * ((upper_var_treated / self.treated_share) + (
+                                    upper_var_control / (1 - self.treated_share)))
+                        fb_var = (1 + self.train_to_est_ratio) * ((lower_var_treated / self.treated_share) + (
+                                    lower_var_control / (1 - self.treated_share)))
+
+                        # split_obj, upper_obj, lower_obj, value = self._eval_fast(train_x, train_y, train_t, val_x,
+                        #                                                          val_y, val_t, x, col)
+                        #
+                        # (train_x1, train_x2, train_y1, train_y2, train_t1, train_t2) \
+                        #     = divide_set(train_x, train_y, train_t, col, value)
+                        #
+                        # # ----------------------------------------------------------------
+                        # # Honest penalty
+                        # # ----------------------------------------------------------------
+                        # var_treat1, var_control1 = variance(train_y1, train_t1)
+                        # var_treat2, var_control2 = variance(train_y2, train_t2)
+                        # # tb_var = (1 + self.train_to_est_ratio) * (
+                        # #         (var_treat1 / (train_nt1 + 1)) + (var_control1 / (train_nc1 + 1)))
+                        # # fb_var = (1 + self.train_to_est_ratio) * (
+                        # #         (var_treat2 / (train_nt2 + 1)) + (var_control2 / (train_nc2 + 1)))
                         # tb_var = (1 + self.train_to_est_ratio) * (
-                        #         (var_treat1 / (train_nt1 + 1)) + (var_control1 / (train_nc1 + 1)))
+                        #         (var_treat1 / self.treated_share) + (var_control1 / (1 - self.treated_share)))
                         # fb_var = (1 + self.train_to_est_ratio) * (
-                        #         (var_treat2 / (train_nt2 + 1)) + (var_control2 / (train_nc2 + 1)))
-                        tb_var = (1 + self.train_to_est_ratio) * (
-                                (var_treat1 / self.treated_share) + (var_control1 / (1 - self.treated_share)))
-                        fb_var = (1 + self.train_to_est_ratio) * (
-                                (var_treat2 / self.treated_share) + (var_control2 / (1 - self.treated_share)))
+                        #         (var_treat2 / self.treated_share) + (var_control2 / (1 - self.treated_share)))
 
                         # combine honest and our objective
                         split_eval = (upper_obj + lower_obj) - (tb_var + fb_var)
@@ -242,15 +264,20 @@ class CausalTreeLearnHonestValidation(CausalTreeLearn):
             # ----------------------------------------------------------------
             # TODO: same note as at the top (not sure if sep val est)
             # ----------------------------------------------------------------
-            y1 = np.concatenate((train_y1, val_y1))
-            y2 = np.concatenate((train_y2, val_y2))
-            t1 = np.concatenate((train_t1, val_t1))
-            t2 = np.concatenate((train_t2, val_t2))
+            # y1 = np.concatenate((train_y1, val_y1))
+            # y2 = np.concatenate((train_y2, val_y2))
+            # t1 = np.concatenate((train_t1, val_t1))
+            # t2 = np.concatenate((train_t2, val_t2))
+            #
+            # best_tb_effect = ace(y1, t1)
+            # best_fb_effect = ace(y2, t2)
+            # tb_p_val = get_pval(y1, t1)
+            # fb_p_val = get_pval(y2, t2)
 
-            best_tb_effect = ace(y1, t1)
-            best_fb_effect = ace(y2, t2)
-            tb_p_val = get_pval(y1, t1)
-            fb_p_val = get_pval(y2, t2)
+            best_tb_effect = ace(val_y1, val_t1)
+            best_fb_effect = ace(val_y2, val_t2)
+            tb_p_val = get_pval(val_y1, val_t1)
+            fb_p_val = get_pval(val_y2, val_t2)
 
             self.obj = self.obj - (node.obj - node.var) + (best_tb_obj + best_fb_obj -
                                                            best_tb_var - best_fb_var)
@@ -260,10 +287,10 @@ class CausalTreeLearnHonestValidation(CausalTreeLearn):
 
             tb = HonestValidationCausalTreeLearnNode(obj=best_tb_obj, effect=best_tb_effect, p_val=tb_p_val,
                                                      node_depth=node.node_depth + 1,
-                                                     var=best_tb_var, num_samples=y1.shape[0])
+                                                     var=best_tb_var, num_samples=val_y1.shape[0])
             fb = HonestValidationCausalTreeLearnNode(obj=best_fb_obj, effect=best_fb_effect, p_val=fb_p_val,
                                                      node_depth=node.node_depth + 1,
-                                                     var=best_tb_var, num_samples=y2.shape[0])
+                                                     var=best_tb_var, num_samples=val_y2.shape[0])
 
             node.true_branch = self._fit(tb, train_x1, train_y1, train_t1, val_x1, val_y1, val_t1)
             node.false_branch = self._fit(fb, train_x2, train_y2, train_t2, val_x2, val_y2, val_t2)
