@@ -50,11 +50,16 @@ class TriggerTreeHonest(TriggerTree):
         # ----------------------------------------------------------------
         # effect and pvals
         # ----------------------------------------------------------------
-        effect, trigger = tau_squared_trigger(y, t, self.min_size, self.quartile)
-        p_val = get_pval_trigger(y, t, trigger)
+        _, trigger = tau_squared_trigger(y, t, self.min_size, self.quartile)
+        effect = ace_trigger(est_y, est_t, trigger)
+        p_val = get_pval_trigger(est_y, est_t, trigger)
         self.root.effect = effect
         self.root.p_val = p_val
         self.root.trigger = trigger
+        # p_val = get_pval_trigger(y, t, trigger)
+        # self.root.effect = effect
+        # self.root.p_val = p_val
+        # self.root.trigger = trigger
 
         # TODO: est ratio is overall?
         self.train_to_est_ratio = est_x.shape[0] / train_x.shape[0]
@@ -70,7 +75,7 @@ class TriggerTreeHonest(TriggerTree):
         # Not sure if i should eval in root or not
         # ----------------------------------------------------------------
         node_eval, trigger, mse = self._eval(train_y, train_t, val_y, val_t)
-        self.root.obj = node_eval
+        self.root.obj = node_eval - current_var
 
         # ----------------------------------------------------------------
         # Add control/treatment means
@@ -134,8 +139,8 @@ class TriggerTreeHonest(TriggerTree):
                 # ----------------------------------------------------------------
                 # Honest penalty
                 # ----------------------------------------------------------------
-                var_treat1, var_control1 = variance(train_y1, train_t1)
-                var_treat2, var_control2 = variance(train_y2, train_t2)
+                var_treat1, var_control1 = variance_trigger(train_y1, train_t1, trigger=tb_trigger)
+                var_treat2, var_control2 = variance_trigger(train_y2, train_t2, trigger=fb_trigger)
                 tb_nt, tb_nc = get_treat_size(train_t1, tb_trigger)
                 fb_nt, fb_nc = get_treat_size(train_t2, fb_trigger)
                 tb_treated_share = tb_nt / train_x.shape[0] if tb_nt > 0 else 1.0
